@@ -1,20 +1,22 @@
 package Mongoose;
 {
-  $Mongoose::VERSION = '0.13';
+  $Mongoose::VERSION = '0.20';
 }
 use MongoDB;
 use MooseX::Singleton;
 use Mongoose::Join;
 use Mongoose::File;
 use Mongoose::Meta::AttributeTraits;
+use MongoDB::Connection;
 use Moose::Util::TypeConstraints;
+class_type 'MongoDB::Connection';
 use Carp;
 
 has '_db' => ( is => 'rw', isa => 'HashRef[MongoDB::Database]' );
 
 has '_connection' => (
     is  => 'rw',
-    isa => 'MongoDB::Connection',
+    isa => 'MongoDB::Connection | Undef',
 );
 
 has '_args' => ( is => 'rw', isa => 'HashRef', default=>sub{{}} );
@@ -131,7 +133,7 @@ Mongoose - MongoDB document to Moose object mapper
 
 =head1 VERSION
 
-version 0.13
+version 0.20
 
 =head1 SYNOPSIS
 
